#!/usr/bin/python

from liqa_bin import my_functions as my

import os, sys

def main():
    
    fileAbsPath = os.path.abspath(os.path.dirname(__file__))
    crtAbsPath = os.getcwd()

    task = ""
    taskList = ["refgene", "quantify", "diff"]
    for i in range(1,len(sys.argv)):
        if sys.argv[i] == "-task" and len(sys.argv)!=i+1:
            task = sys.argv[i+1]
    if (task not in taskList):
        print("\nPlease specify task (liqa -task <task>):\n")
        print("\trefgene:   preprocess reference file\n")
        print("\tquantify:   quantify isoform expression\n")
        print("\tdiff:   detect differential splicing gene/isoform\n")

    if task == "refgene":
        validArgList = ["-task", "-ref", "-out"]
        addAbsPath = [0, 1, 3]
        message = "liqa -task refgene -ref <reference_file> -out <output_file>"
        inputs = my.parse_argument(validArgList, addAbsPath, message)
        refFile = inputs[1]
        outFile = inputs[2]
        myCommand = "perl " + fileAbsPath + "/liqa_function/PreProcess.pl -r " + refFile + " -o " + outFile
        os.system(myCommand)

    if task == "quantify":
        validArgList = ["-task", "-refgene", "-bam", "-out", "-max_distance", "-f_weight"]
        addAbsPath = [0, 1, 1, 3, 0, 0]
        message = "liqa -task quantify -refgene <refgene_file> -bam <bam_file> -out <output_file> -max_distance <max distance> -f_weight <weight of F function>"
        inputs = my.parse_argument(validArgList, addAbsPath, message)
        refFile = inputs[1]
        bamFile = inputs[2]
        outFile = inputs[3]
        misMatch = inputs[4]
        weightF = inputs[5]
        myCommand = "python " + fileAbsPath + "/liqa_function/LRSeq_new.py -ref " + refFile + " -bam " +  bamFile + " -out " + outFile + " -mismatch " + misMatch + " -f_weight " + weightF
        os.system(myCommand)

    if task == "diff":
        validArgList = ["-task", "-ref", "-est"]
        addAbsPath = [0, 1, 1]
        message = "liqa -task refgene -ref <refgene_file> -est <isoformRelativeAbundances_estimations>"
        inputs = my.parse_argument(validArgList, addAbsPath, message)
        refFile = inputs[1]
        estFile = inputs[2]
        myCommand = "python " + fileAbsPath + "/liqa_function/Diff.py -r " + refFile + " -est " + estFile
        os.system(myCommand)

if __name__ == "__main__":
    main()




#!/usr/bin/python

from __future__ import print_function # load print function in python3
from collections import defaultdict  
import sys, os

# set up auto dictionary function
def auto_dict():
    return defaultdict(auto_dict)

# preliminary setup
scriptAbsPath = os.path.dirname(os.path.abspath(__file__)) # get absolute path of python script
while not os.path.isdir(scriptAbsPath+"/tmp"): os.system("mkdir "+scriptAbsPath+"/tmp")

# checking out argments
validArgList = ["-est", "-ref"]
for argIndex in range(1,len(sys.argv)):
    if sys.argv[argIndex][0] == "-" and sys.argv[argIndex] not in validArgList :
        print("Argument \'"+sys.argv[argIndex]+"\' is invalid!")
        sys.exit()
        
estFileExists = 0
refFileExists = 0
for argIndex in range(1,len(sys.argv)):
    if sys.argv[argIndex] == "-est":  ## load in estimation file
        argIndex += 1
        estFileAbsPath = os.path.dirname(os.path.abspath(sys.argv[argIndex]))
        estTmp = sys.argv[argIndex].split("/")
        estimationFile = estFileAbsPath + "/" + estTmp[len(estTmp)-1]
        estFileExists = 1
    elif sys.argv[argIndex] == "-ref":  ## load in annotation file
        argIndex += 1
        refFileAbsPath = os.path.dirname(os.path.abspath(sys.argv[argIndex]))
        refTmp = sys.argv[argIndex].split("/")
        refGeneFile = refFileAbsPath + "/" + refTmp[len(refTmp)-1]
        refFileExists = 1

if estFileExists == 0 or refFileExists == 0: ## lack enough arguments
    print("Please provide arguments:")
    print("-est\tIsoform relative abundances estimation file")
    print("-ref\tGene annotation file")
    sys.exit()    



### convert gene annotation file to compatible matrix

getRefGeneCommand = "python " + scriptAbsPath + "/bin/getCompatibleMatrix.py " + refGeneFile + " > " + scriptAbsPath + "/tmp/isoformCompatibleMatrix"  
command1Done = 0
while command1Done == 0:
    print("Isoform compatible matrix conversion: Processing...")
    os.system(getRefGeneCommand) 
    command1Done = 1

print("Isoform compatible matrix conversion: Done!")


### calculate estimated exon inclusion levels
getExonIncLvlCommand = "python " + scriptAbsPath + "/bin/getExonIncLvl.py " + scriptAbsPath + "/tmp/isoformCompatibleMatrix" + " " + estimationFile + " > " + scriptAbsPath + "/tmp/exonInclusionLevels"
command2Done = 0
while command2Done == 0:
    print("Exon inclusion levels calculation: Processing...")
    os.system(getExonIncLvlCommand)
    command2Done = 1

print("Exon inclusion levels calculation: Done!")

### test DAS event
testDASCommand = "Rscript " + scriptAbsPath + "/bin/testDAS.R " + scriptAbsPath + "/tmp/exonInclusionLevels " + scriptAbsPath + "/tmp/tmpResultsGene "+ scriptAbsPath +"/tmp/tmpResultsExon"
command3Done = 0
while command3Done == 0:
    print("DAS testing: Start to process...")
    os.system(testDASCommand)
    command3Done = 1

print("DAS testing: Done!")


### summarize results
summarizeCommand = "python " + scriptAbsPath + "/bin/summarize.py " + scriptAbsPath + "/tmp/tmpResultsExon " + scriptAbsPath + "/tmp/tmpResultsGene "
summarizeCommand = summarizeCommand + scriptAbsPath + "/tmp/exonInclusionLevels " + estimationFile + " " + scriptAbsPath + "/exonDASResults " + scriptAbsPath + "/geneDASResults"
command4Done = 0
while command4Done == 0:
    print("Summarizing...")
    os.system(summarizeCommand)
    command4Done = 1

print("Done!")

### delete temporary files
deleteCommand = "rm -r " + scriptAbsPath + "/tmp"
os.system(deleteCommand)



#!/usr/bin/python

from __future__ import print_function
from collections import defaultdict
import math, sys, os, re, time

# set up auto dictionary function
def auto_dict():
    return defaultdict(auto_dict)

# make a directory
def mk_dir(path):
    check = os.path.isdir(path)
    if not check:
        os.system("mkdir " + path)
    return

# parse arguments
def parse_argument(validArgList, addAbsPath, warnMessage):    
    for argIndex in range(1,len(sys.argv)):
        if sys.argv[argIndex][0] == "-" and sys.argv[argIndex] not in validArgList :
            print("Argument \'"+sys.argv[argIndex]+"\' is invalid!")
            sys.exit()

    # assign arguments to a list
    outList = []
    for i in range(0, len(validArgList)):
        for argIndex in range(1,len(sys.argv)):
            if sys.argv[argIndex] == validArgList[i]:
                argIndex += 1
                if "~" in sys.argv[argIndex]:
                    sys.argv[argIndex] = os.path.expanduser(sys.argv[argIndex])
                fileAbsPath = os.path.dirname(os.path.abspath(sys.argv[argIndex]))
                fileTmp = sys.argv[argIndex].split("/")
                if addAbsPath[i] == 1: # target file
                    fileTmp = fileAbsPath + "/" + fileTmp[len(fileTmp)-1]
                    check = os.path.exists(fileTmp)
                    if not check:
                        print(fileTmp+" does not exist!")
                        sys.exit()
                if addAbsPath[i] == 3: # create target file
                    fileTmp = fileAbsPath + "/" + fileTmp[len(fileTmp)-1]
                if addAbsPath[i] == 0: # value
                    fileTmp = fileTmp[len(fileTmp)-1]
                if addAbsPath[i] == 2: # target directory
                    fileTmp = os.path.abspath(sys.argv[argIndex])
                    check = os.path.isdir(fileTmp)
                    if not check:
                        print(fileTmp+" does not exist!")
                        sys.exit()
                outList.append(fileTmp)
    
    if len(outList) != len(validArgList):
        print(warnMessage)
        sys.exit()
    return outList

# check modules ### NOT WORKING!!
import imp
def check_module_exists(name):
    try:
        imp.find_module(name)
    except ImportError:
        return False
    return True

def check_module(module):
    x = check_module_exists(module)
    if x:
        print("Module \'" + module + "\' is installed.")
    if not x:
        print("Module \'" + module + "\' is NOT installed!")
    return

# check program
from subprocess import Popen, PIPE

def check_program_exists(name):
    p = Popen(['/usr/bin/which', name], stdout=PIPE, stderr=PIPE)
    p.communicate()
    return p.returncode == 0

def check_program(program):
    x = check_program_exists(program)
    if x:
        print("Program \'" + program + "\' is installed.")
    if not x:
        print("Program \'" + program + "\' is NOT installed!")
    return



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="liqa",
    version="1.1.6",
    author="Yu Hu",
    author_email="huyu999999@gmail.com",
    description="A statistical tool to quantify isoform-specific expression using long-read RNA-seq",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/WGLab/LIQA",
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    #install_requires=["pysam", "lifelines"],
    #python_requires='>=3.6',
    packages=["liqa_src","liqa_bin"],
    package_dir={"liqa_src":"liqa_src","liqa_bin":"liqa_src/liqa_bin"},
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "liqa=liqa_src.liqa:main",
        ]
    },
)
